[−][src]Crate gstreamer_base
Re-exports
pub use functions::*; |
Modules
| functions | |
| functions | |
| prelude |
Structs
| Adapter | |
| AdapterClass | |
| BaseSink | |
| BaseSinkClass | |
| BaseSrc | |
| BaseSrcClass | |
| BaseTransform | |
| BaseTransformClass | |
| Continue | Continue calling the closure in the future iterations or drop it. |
| Error | A generic error capable of representing various error domains (types). |
| FlowCombiner | |
| PushSrc | |
| PushSrcClass | |
| TypedValue | A statically typed |
| UniqueAdapter | |
| UniqueAdapterMap | |
| UniqueFlowCombiner | |
| Value | A generic value capable of carrying various types. |
Enums
| Type | A GLib or GLib-based library type |
Constants
| NONE_BASE_SINK | |
| NONE_BASE_SRC | |
| NONE_BASE_TRANSFORM | |
| NONE_PUSH_SRC |
Traits
| BaseSinkExt | |
| BaseSrcExt | |
| BaseTransformExt | |
| Cast | Upcasting and downcasting support. |
| IsA | Declares the "is a" relationship. |
| StaticType | Types that are supported by GLib dynamic typing. |
| ToValue | Converts to |
Functions
| type_find_helper | |
| type_find_helper_for_buffer | |
| type_find_helper_for_extension |